@@ -7,13 +7,15 @@ use std::path::Path;
 use crate::openapi_generator::OpenApiGenerator;
 
 pub fn generate_oapi_server_stubs(
-    specification: impl AsRef<Path>,
+    root_oapi_dir: impl AsRef<Path>,
+    specification: &str,
     destination: impl AsRef<Path>,
 ) -> Result<()> {
-    let mut openapi_generator = OpenApiGenerator::new(&specification).context(format!(
-        "Cannot create OpenAPI generator with specifications at `{}`",
-        specification.as_ref().to_string_lossy()
-    ))?;
+    let mut openapi_generator =
+        OpenApiGenerator::new(root_oapi_dir, specification).context(format!(
+            "Cannot create OpenAPI generator with specifications at `{}`",
+            specification
+        ))?;
     openapi_generator.render(&destination).context(format!(
         "Cannot render to `{}`",
         destination.as_ref().to_string_lossy()
